@@ -2,7 +2,7 @@ package Business::IBAN::Validator;
 use warnings;
 use strict;
 
-our $VERSION = "0.07_01";
+our $VERSION = 0.02;
 
 use Hash::Util qw/unlock_hash lock_hash/;
 use Business::IBAN::Database;
@@ -137,17 +137,8 @@ Return 1 on success.
 
 Return the SEPA status of the country (as denoted by the first two letters).
 
-=head1 COPYRIGHT
+=head1 STUFF
 
-E<copy> MMXIII-MMXV - Abe Timmerman <abeltje@cpan.org>
-
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+(c) MMXIII - Abe Timmerman <abeltje@cpan.org>
 
 =cut
